/* global mateoColorScheme, Color */

/**
 * Add a listener to the Color Scheme control to update other color controls to new values/defaults.
 * Also trigger an update of the Color Scheme CSS when a color is changed.
 */
(function (api) {
  var cssTemplate = wp.template('mateo-color-scheme'),
      colorSchemeKeys = ['primary', 'primaryLight', 'primaryDark', 'textOnPrimary', 'link', 'textBody', 'title', 'contentBgr', 'pageBgr'],
      colorSettings = ['primary', 'primaryLight', 'primaryDark', 'textOnPrimary', 'link', 'textBody', 'title', 'contentBgr', 'pageBgr'];
  api.controlConstructor.select = api.Control.extend({
    ready: function ready() {
      if ('color_scheme' === this.id) {
        this.setting.bind('change', function (value) {
          var colors = mateoColorScheme[value].colors;
          var color = colors.primary;
          api('primary').set(color);
          api.control('primary').container.find('.color-picker-hex').data('data-default-color', color).wpColorPicker('defaultColor', color);
          color = colors.primaryLight;
          api('primaryLight').set(color);
          api.control('primaryLight').container.find('.color-picker-hex').data('data-default-color', color).wpColorPicker('defaultColor', color);
          color = colors.primaryDark;
          api('primaryDark').set(color);
          api.control('primaryDark').container.find('.color-picker-hex').data('data-default-color', color).wpColorPicker('defaultColor', color);
          color = colors.textOnPrimary;
          api('textOnPrimary').set(color);
          api.control('textOnPrimary').container.find('.color-picker-hex').data('data-default-color', color).wpColorPicker('defaultColor', color);
          color = colors.link;
          api('link').set(color);
          api.control('link').container.find('.color-picker-hex').data('data-default-color', color).wpColorPicker('defaultColor', color);
          color = colors.textBody;
          api('textBody').set(color);
          api.control('textBody').container.find('.color-picker-hex').data('data-default-color', color).wpColorPicker('defaultColor', color);
          color = colors.title;
          api('title').set(color);
          api.control('title').container.find('.color-picker-hex').data('data-default-color', color).wpColorPicker('defaultColor', color);
          color = colors.contentBgr;
          api('contentBgr').set(color);
          api.control('contentBgr').container.find('.color-picker-hex').data('data-default-color', color).wpColorPicker('defaultColor', color);
          color = colors.pageBgr;
          api('pageBgr').set(color);
          api.control('pageBgr').container.find('.color-picker-hex').data('data-default-color', color).wpColorPicker('defaultColor', color);
        });
      }
    }
  }); // Generate the CSS for the current Color Scheme.

  function updateCSS() {
    var scheme = api('color_scheme')(),
        colors = _.object(colorSchemeKeys, mateoColorScheme[scheme].colors); // Merge in color scheme overrides.


    _.each(colorSettings, function (setting) {
      colors[setting] = api(setting)();
    }); // Add derived colors.


    colors['primarySubmenuBgr'] = Color(colors['primary']).toCSS('rgba', 0.9);
    colors['switchCheckedBgr'] = Color(colors['primary']).lighten(28).desaturate(32).toString();
    colors['currentMenuItem'] = Color(colors['textOnPrimary']).toCSS('rgba', 0.2);
    colors['menuItemHover'] = colors['textOnPrimary'];
    colors['bmdLabelOnPrimary'] = colors['textOnPrimary'];
    colors['bmdLabelFooter'] = Color(colors['textOnPrimary']).toCSS('rgba', 0.8);
    colors['footerInputInvalid'] = Color(colors['textOnPrimary']).toCSS('rgba', 0.26);
    colors['preBgr'] = Color(colors['textBody']).toCSS('rgba', 0.01);
    colors['lightTextBody'] = Color(colors['textBody']).toCSS('rgba', 0.8);
    colors['varyLightTextBody'] = Color(colors['textBody']).toCSS('rgba', 0.1);
    api.previewer.send('update-color-scheme-css', cssTemplate(colors));
  } // Update the CSS whenever a color setting is changed.


  _.each(colorSettings, function (setting) {
    api(setting, function (setting) {
      setting.bind(updateCSS);
    });
  }); // header_textcolor is a shortcut for textOnPrimary.


  api('textOnPrimary', function (setting) {
    setting.bind(function () {
      api('header_textcolor').set(setting.get());
    });
  });
  api('header_textcolor', function (setting) {
    setting.bind(function () {
      api('textOnPrimary').set(setting.get());
    });
  });
})(wp.customize);
