<?php
/**
 * The header for our theme
 *
 * This is the template that displays all of the <head> section and everything up until <div id="content">
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package mateo
 */

$mateo_small_menu = null;
$mateo_big_menu   = mateo_nav_menu(
	array(
		'theme_location'  => 'menu-1',
		'menu_id'         => 'primary-menu',
		'menu_class'      => 'main-menu',
		'container'       => 'div',
		'container_class' => 'collapse navbar-collapse',
	)
);
if ( $mateo_big_menu ) {
	$mateo_small_menu = mateo_nav_menu(
		array(
			'theme_location'  => 'menu-1',
			'menu_id'         => 's-primary-menu',
			'menu_class'      => 's-main-menu',
			'container'       => 'div',
			'container_class' => 'small-main-container',
		)
	);
}

?>
<!doctype html>
<html <?php language_attributes(); ?>>
<head>
	<meta charset="<?php bloginfo( 'charset' ); ?>">
	<meta name="viewport" content="width=device-width, initial-scale=1">
	<link rel="profile" href="https://gmpg.org/xfn/11">
	<?php wp_head(); ?>
</head>
<body id="wrapper" <?php body_class(); ?>>
<?php wp_body_open(); ?>
<a class="skip-link screen-reader-text" href="#content"><?php esc_html_e( 'Skip to content', 'mateo' ); ?></a>
<header class="container-fluid">
	<div class="container">
		<nav class="navbar navbar-expand-lg">
			<div class="site-branding">
				<div class="logo-container">
					<?php
					$mateo_custom_logo = get_custom_logo();
					if ( $mateo_custom_logo ) {
						echo $mateo_custom_logo; // phpcs:ignore
					}
					?>
				</div>
				<div class="site-title">
					<a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home" title="<?php echo esc_attr( get_bloginfo( 'name' ) ); ?>">
						<?php bloginfo( 'name' ); ?>
					</a>
				</div>
			</div>
			<?php if ( $mateo_big_menu ) : ?>

				<div class="main-menu-container hide-overflow">
					<?php echo $mateo_big_menu; // phpcs:ignore
					// If there is no menu no need to display the button for small menu.
					?>
					<button class="navbar-toggler" type="button"
							aria-controls="x-primary-menu"  aria-expanded="false" aria-label="<?php echo esc_attr( __( 'Show menu', 'mateo' ) ); ?>">
						<span class="navbar-toggler-icon" aria-hidden="true"><i class="menu-burger"></i></span>
					</button>
				</div>


			<?php endif; ?>
		</nav>
		<?php
		if ( $mateo_small_menu ) {
			echo $mateo_small_menu; // phpcs:ignore
		}
		?>
	</div>

</header>
<div class="container-fluid header-featured<?php echo mateo_has_featured_img() ? ' has-image' : ''; ?>">
	<div class="container page-header">
		<h1 class="page-title">
			<span>
		<?php if ( is_archive() ) : ?>
			<?php
			the_archive_title();
			?>
		<?php elseif ( is_search() ) : ?>
			<?php esc_html_e( 'Search: ', 'mateo' ); ?><?php echo get_search_query(); ?>
		<?php elseif ( is_404() ) : ?>
			<?php esc_html_e( 'Page not found', 'mateo' ); ?>
		<?php else : ?>
					<?php
					$mateo_title = single_post_title( '', false );
					if ( ! $mateo_title ) {
						bloginfo();
					} else {
						echo $mateo_title;  // phpcs:ignore
					}
					unset( $mateo_title );
					?>
		<?php endif; ?>
			</span>
		</h1>
	</div>
</div>
<div id="content" class="site-content container">
	<div class="row">
		<div class="col-12 <?php echo is_active_sidebar( 'sidebar-1' ) ? 'col-lg-9' : ''; ?>">
